@@ -1,11 +1,8 @@
 #include <torch.h>
 
 // [[Rcpp::export]]
-std::string cpp_dtype_to_string(XPtrTorchDtype dtype) {
-  auto s = lantern_Dtype_type(dtype.get());
-  auto out = std::string(s);
-  lantern_const_char_delete(s);
-  return out;
+torch::string cpp_dtype_to_string(XPtrTorchDtype dtype) {
+  return torch::string(lantern_Dtype_type(dtype.get()));
 }
 
 // [[Rcpp::export]]
