@@ -100,8 +100,3 @@ torch::string cpp_torch_show_config () {
 torch::string cpp_torch_parallel_info () {
   return torch::string(lantern_torch_parallel_info());
 }
-
-// [[Rcpp::export]]
-void cpp_benchmark_debug () {
-  _lantern_benchmark_debug();
-}
