@@ -157,12 +157,20 @@ test_that("load a state dict created in python", {
   # value = {'ones': ones, 'twos': twos}
   # torch.save(value, "assets/state_dict.pth", _use_new_zipfile_serialization=True)
 
-  dict <- load_state_dict("assets/state_dict.pth")
+  dict <- load_state_dict(test_path("assets/state_dict.pth"))
   expect_equal(names(dict), c("ones", "twos"))
   expect_equal_to_tensor(dict$ones, torch_ones(3, 5))
   expect_equal_to_tensor(dict$twos, torch_ones(3, 5) * 2)
 })
 
+test_that("can load a state dict that contains an ordered dict", {
+
+  dict <- load_state_dict(test_path("assets/ordered_dict.pt"))
+  expect_equal(names(dict), c("weight", "bias"))
+  expect_tensor_shape(dict$weight, c(10, 10))
+  expect_tensor_shape(dict$bias, c(10))
+})
+
 test_that("Can load a torch v0.2.1 model", {
   skip_on_os("windows")
 
